# esp-idf-kconfig

The ```esp-idf-kconfig``` package is part of the [ESP-IDF](https://github.com/espressif/esp-idf) SDK for Espressif products and is automatically installed.

It is responsible for enabling project configuration using the ```kconfig``` language, providing IDE support for configuration and configuration documentation generation.

For more information about how it works go to the [documentation](https://github.com/espressif/esp-idf-kconfig/blob/master/docs/DOCUMENTATION.md).
